SearchText class

Mixed-in types
Annotations
  • @MappableClass.new()

Constructors

SearchText({required List<String> returnFields, required Map<String, dynamic> inputs, int topK = 10, int rerankTopK = 5, String rerankModel = "bge-reranker-v2-m3", String? rerankInput, List<String>? rerankReturnFields})
SearchText.basic({required String query, required String textKey, bool rerank = true, int topK = 10, int rerankTopK = 5, String rerankModel = "bge-reranker-v2-m3"})
factory

Properties

copyWith SearchTextCopyWith<SearchText, SearchText, SearchText>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
inputs Map<String, dynamic>
final
rerankInput String?
final
rerankModel String
final
rerankReturnFields List<String>?
final
rerankTopK int
final
returnFields List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topK int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
inherited
toMap() Map<String, dynamic>
inherited
toPMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited