SearchTextCopyWith<$R, $In extends SearchText, $Out> class
abstract
- Available extensions
Constructors
Properties
-
$asSearchText
→ SearchTextCopyWith<
$R, SearchText, $Out> -
Available on ObjectCopyWith<
$R, SearchText, $Out> , provided by the SearchTextValueCopy extensionno setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
inputs
→ MapCopyWith<
$R, String, dynamic, ObjectCopyWith< $R, dynamic, dynamic> > -
no setter
-
rerankReturnFields
→ ListCopyWith<
$R, String, ObjectCopyWith< ?$R, String, String> > -
no setter
-
returnFields
→ ListCopyWith<
$R, String, ObjectCopyWith< $R, String, String> > -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$chain<
$R2, $Out2> (Then< $Out2, $R2> t) → SearchTextCopyWith<$R2, $In, $Out2> -
$delta(
Map< String, dynamic> delta) → $R -
inherited
-
$merge(
$In value) → $R -
inherited
-
$update(
$Out transform($In)) → $R -
inherited
-
call(
{List< String> ? returnFields, Map<String, dynamic> ? inputs, int? topK, int? rerankTopK, String? rerankModel, String? rerankInput, List<String> ? rerankReturnFields}) → $R -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited